@@ -2,25 +2,29 @@
 from __future__ import print_function
 
 import sys
-from blessings import Terminal
+from blessed import Terminal
 
 from inquirer import errors
 from inquirer import events
+from inquirer import themes
 
 from ._text import Text
+from ._editor import Editor
 from ._password import Password
 from ._confirm import Confirm
 from ._list import List
 from ._checkbox import Checkbox
+from ._path import Path
 
 
 class ConsoleRender(object):
-    def __init__(self, event_generator=None, *args, **kwargs):
+    def __init__(self, event_generator=None, theme=None, *args, **kwargs):
         super(ConsoleRender, self).__init__(*args, **kwargs)
         self._event_gen = event_generator or events.KeyEventGenerator()
         self.terminal = Terminal()
         self._previous_error = None
         self._position = 0
+        self._theme = theme or themes.Default()
 
     def render(self, question, answers=None):
         question.answers = answers or {}
@@ -29,7 +33,10 @@ class ConsoleRender(object):
             return question.default
 
         clazz = self.render_factory(question.kind)
-        render = clazz(question, self.terminal)
+        render = clazz(question,
+                       terminal=self.terminal,
+                       theme=self._theme,
+                       show_default=question.show_default)
 
         self.clear_eos()
 
@@ -63,6 +70,8 @@ class ConsoleRender(object):
 
     def _print_options(self, render):
         for message, symbol, color in render.get_options():
+            if hasattr(message, 'decode'):  # python 2
+                message = message.decode('utf-8')
             self.print_line(' {color}{s} {m}{t.normal}',
                             m=message, color=color, s=symbol)
 
@@ -72,25 +81,41 @@ class ConsoleRender(object):
         header = (base[:self.width - 9] + '...'
                   if len(base) > self.width - 6
                   else base)
-        header += ': {c}'.format(c=render.get_current_value())
+        default_value = ' ({color}{default}{normal})'.format(
+            default=render.question.default,
+            color=self._theme.Question.default_color,
+            normal=self.terminal.normal
+        )
+        show_default = render.question.default and render.show_default
+        header += default_value if show_default else ''
+        msg_template = "{t.move_up}{t.clear_eol}{tq.brackets_color}["\
+                       "{tq.mark_color}?{tq.brackets_color}]{t.normal} {msg}"
+
+        # ensure any user input with { or } will not cause a formatting error
+        escaped_current_value = (
+            str(render.get_current_value())
+            .replace('{', '{{')
+            .replace('}', '}}')
+        )
         self.print_str(
-            '\n{t.move_up}{t.clear_eol}[{t.yellow}?{t.normal}] {msg}',
+            '\n%s: %s' % (msg_template, escaped_current_value),
             msg=header,
-            lf=not render.title_inline)
+            lf=not render.title_inline,
+            tq=self._theme.Question)
 
     def _process_input(self, render):
         try:
             ev = self._event_gen.next()
             if isinstance(ev, events.KeyPressed):
                 render.process_input(ev.value)
+        except errors.ValidationError as e:
+            self._previous_error = e.value
         except errors.EndOfInput as e:
             try:
                 render.question.validate(e.selection)
                 raise
             except errors.ValidationError as e:
-                self._previous_error = ('"{e}" is not a valid {q}.'
-                                        .format(e=e.value,
-                                                q=render.question.name))
+                self._previous_error = render.handle_validation_error(e)
 
     def _relocate(self):
         print(self._position * self.terminal.move_up, end='')
@@ -119,7 +144,7 @@ class ConsoleRender(object):
             self.render_in_bottombar(
                 '{t.red}{s}{t.normal}{t.bold}{msg}{t.normal} '
                 .format(msg=message, s=symbol, t=self.terminal)
-                )
+            )
 
     def render_in_bottombar(self, message):
         with self.terminal.location(0, self.height - 2):
@@ -133,11 +158,13 @@ class ConsoleRender(object):
     def render_factory(self, question_type):
         matrix = {
             'text': Text,
+            'editor': Editor,
             'password': Password,
             'confirm': Confirm,
             'list': List,
             'checkbox': Checkbox,
-            }
+            'path': Path,
+        }
 
         if question_type not in matrix:
             raise errors.UnknownQuestionTypeError()
