@@ -33,7 +33,7 @@ class TextTest(unittest.TestCase):
         self.set_name()
         self.set_surname()
         self.set_phone('abcde')
-        self.sut.expect('"abcde" is not a valid phone', timeout=1)
+        self.sut.expect('I don\'t like your phone number!', timeout=1)
         self.sut.sendline(5*key.BACKSPACE + '12345')
         self.sut.expect_list([re.compile(b"'name': 'foo'"),
                               re.compile(b"'surname': 'bar'"),
